#ifndef u_OMX_IMPORT_FRONTEND_STATE_H
#define u_OMX_IMPORT_FRONTEND_STATE_H

int matchCaseInsensitive(const char *source, const char *target);
void omxProcessCheckpointOptions(SEXP checkpointList);

#endif // #define u_OMX_IMPORT_FRONTEND_STATE_H
